@@ -6,11 +6,11 @@ Apache2::Controller::Directives - server config directives for A2C
 
 =head1 VERSION
 
-Version 0.101.111 - BETA TESTING (ALPHA?)
+Version 0.110.000 - BETA TESTING (ALPHA?)
 
 =cut
 
-our $VERSION = version->new('0.101.111');
+our $VERSION = version->new('0.110.000');
 
 =head1 SYNOPSIS
 
@@ -18,7 +18,7 @@ our $VERSION = version->new('0.101.111');
  PerlLoadModule Apache2::Controller::Directives
 
  # for Apache2::Controller::Render::Template settings:
- A2CRenderTemplatePath /var/myapp/templates
+ A2C_Render_Template_Path /var/myapp/templates
 
  # etc.
 
@@ -37,61 +37,70 @@ use Apache2::Const -compile => qw( OR_ALL TAKE1 ITERATE ITERATE2 );
 
 my @directives = (
 
-    # template rendering
-    { 
-        name            => 'A2CRenderTemplatePath',
-        func            => __PACKAGE__.'::A2CRenderTemplatePath',
+    # dispatch
+    {
+        name            => 'A2C_Dispatch_Map',
+        func            => __PACKAGE__.'::A2C_Dispatch_Map',
         req_override    => Apache2::Const::OR_ALL,
         args_how        => Apache2::Const::ITERATE,
-        errmsg          => 'A2CRenderTemplatePath /primary/path [/second ... [/n]]',
+        errmsg          => 'A2C_Dispatch_Map /path/to/yaml/syck/dispatch/map/file',
+    },
+
+    # template rendering
+    { 
+        name            => 'A2C_Render_Template_Path',
+        func            => __PACKAGE__.'::A2C_Render_Template_Path',
+        req_override    => Apache2::Const::OR_ALL,
+        args_how        => Apache2::Const::ITERATE,
+        errmsg          => 'A2C_Render_Template_Path /primary/path [/second ... [/n]]',
     },
     {
-        name            => 'A2CRenderTemplateOpts',
-        func            => __PACKAGE__.'::A2CRenderTemplateOpts',
+        name            => 'A2C_Render_Template_Opts',
+        func            => __PACKAGE__.'::A2C_Render_Template_Opts',
         req_override    => Apache2::Const::OR_ALL,
         args_how        => Apache2::Const::ITERATE2,
         errmsg          => q{
             # specify Template Toolkit options:
-            A2CRenderTemplateOpts INTERPOLATE 1
-            A2CRenderTemplateOpts PRE_PROCESS header scripts style
-            A2CRenderTemplateOpts POST_CHOMP  1
+            A2C_Render_Template_Opts INTERPOLATE 1
+            A2C_Render_Template_Opts PRE_PROCESS header scripts style
+            A2C_Render_Template_Opts POST_CHOMP  1
         },
     },
 
     # session stuff
     {
-        name            => 'A2CSessionClass',
-        func            => __PACKAGE__.'::A2CSessionClass',
+        name            => 'A2C_Session_Class',
+        func            => __PACKAGE__.'::A2C_Session_Class',
         req_override    => Apache2::Const::OR_ALL,
         args_how        => Apache2::Const::TAKE1,
-        errmsg          => 'example: A2CSessionClass Apache::Session::File'
+        errmsg          => 'example: A2C_Session_Class Apache::Session::File'
     },
     {
-        name            => 'A2CSessionOptions',
-        func            => __PACKAGE__.'::A2CSessionOptions',
+        name            => 'A2C_Session_Opts',
+        func            => __PACKAGE__.'::A2C_Session_Opts',
         req_override    => Apache2::Const::OR_ALL,
         args_how        => Apache2::Const::ITERATE2,
         errmsg          => q{
             # specify options for chosen Apache::Session subclass.
             # example:
-            A2CSessionOptions   Directory       /tmp/sessions
-            A2CSessionOptions   LockDirectory   /var/lock/sessions
+            A2C_Session_Opts   Directory       /tmp/sessions
+            A2C_Session_Opts   LockDirectory   /var/lock/sessions
         },
     },
     {
-        name            => 'A2CSessionCookieOptions',
-        func            => __PACKAGE__.'::A2CSessionCookieOptions',
+        name            => 'A2C_Session_Cookie_Opts',
+        func            => __PACKAGE__.'::A2C_Session_Cookie_Opts',
         req_override    => Apache2::Const::OR_ALL,
         args_how        => Apache2::Const::ITERATE2,
         errmsg          => q{
             # specify Apache2::Cookie options for session cookie.
             # example:
-            A2CSessionCookieOptions   name       myapp_sessionid
-            A2CSessionCookieOptions   expires    +3M
+            A2C_Session_Cookie_Opts   name       myapp_sessionid
+            A2C_Session_Cookie_Opts   expires    +3M
         },
     },
 
-    # ...SQL::Connector
+    # A2C:DBI::Connector
     {
         name            => 'A2C_DBI_DSN',
         req_override    => Apache2::Const::OR_ALL,
@@ -120,13 +129,72 @@ my @directives = (
             A2C_DBI_Options AutoCommit 0
         },
     },
+    {
+        name            => 'A2C_DBI_Cleanup',
+        req_override    => Apache2::Const::OR_ALL,
+        args_how        => Apache2::Const::TAKE1,
+        errmsg          => 'example: A2C_DBI_Cleanup 1',
+    },
+    {
+        name            => 'A2C_DBI_Class',
+        req_override    => Apache2::Const::OR_ALL,
+        args_how        => Apache2::Const::TAKE1,
+        errmsg          => 'example: A2C_DBI_Class MyApp::DBI',
+    },
+    {
+        name            => 'A2C_DBI_Pnotes_Name',
+        req_override    => Apache2::Const::OR_ALL,
+        args_how        => Apache2::Const::TAKE1,
+        errmsg          => 'example: A2C_DBI_Pnotes_Name reader',
+    },
 );
 
 Apache2::Module::add(__PACKAGE__, \@directives);
 
-=head1 DIRECTIVES
+=head1 Apache2::Controller::Dispatch
 
-=head2 A2CRenderTemplatePath
+See L<Apache2::Controller::Dispatch>
+
+=head2 A2C_Dispatch_Map
+
+This is the path to a file compatible with L<YAML::Syck>.
+If you do not provide a C<< dispatch_map() >> subroutine,
+the hash will be loaded with this file.
+
+Different subclasses of L<Apache2::Controller::Dispatch>
+have different data structures.  YMMV.
+
+Or, if you just specify a package name, it will generate
+a dispatch map with one 'default' entry with that package.
+
+=cut
+
+sub A2C_Dispatch_Map {
+    my ($self, $parms, $value) = @_;
+
+    if ($value =~ m{ :: }mxs) {
+        $self->{A2C_Dispatch_Map} = { default => $value };
+        return;
+    }
+
+    my $file = $value;
+  # DEBUG("using file '$file' as A2C_Dispatch_Map");
+    croak "A2C_Dispatch_Map $file does not exist or is not readable."
+        if !(-e $file && -f _ && -r _);
+    
+    # why not go ahead and load the file!
+    $self->{A2C_Dispatch_Map} = LoadFile($file)
+        || croak "Could not load A2C_Dispatch_Map $file: $OS_ERROR";
+
+  # DEBUG("success!");
+    return;
+}
+
+=head1 Apache2::Controller::Render::Template
+
+See L<Apache2::Controller::Render::Template>.
+
+=head2 A2C_Render_Template_Path
 
 This is the base path for templates used by 
 Apache2::Controller::Render::Template.  The directive takes only
@@ -139,7 +207,7 @@ this does not appear to work?  It returns an empty hash.)
 
 =cut
 
-sub A2CRenderTemplatePath {
+sub A2C_Render_Template_Path {
     my ($self, $parms, @directories) = @_;
 
     # uhh... this doesn't work?
@@ -149,21 +217,21 @@ sub A2CRenderTemplatePath {
   # }) });
   # DEBUG("server is ".$parms->server);
 
-    croak("A2CRenderTemplatePath '$_' does not exist or is not readable.") 
+    croak("A2C_Render_Template_Path '$_' does not exist or is not readable.") 
         for grep !( -d $_ && -r _ ), @directories;
 
-    my $current = $self->{A2CRenderTemplatePath} || [ ];
+    my $current = $self->{A2C_Render_Template_Path} || [ ];
   # DEBUG("pushing (@directories) to (@{$current})");
 
-    push @{ $self->{A2CRenderTemplatePath} }, @directories;
+    push @{ $self->{A2C_Render_Template_Path} }, @directories;
 }
 
-=head2 A2CRenderTemplateOpts
+=head2 A2C_Render_Template_Opts
 
  <location "/where/template/is/used">
-     A2CRenderTemplateOpts INTERPOLATE 1
-     A2CRenderTemplateOpts PRE_PROCESS header meta style scripts
-     A2CRenderTemplateOpts POST_CHOMP  1
+     A2C_Render_Template_Opts INTERPOLATE 1
+     A2C_Render_Template_Opts PRE_PROCESS header meta style scripts
+     A2C_Render_Template_Opts POST_CHOMP  1
  </location>
 
 Options for Template Toolkit.  See L<Template>.
@@ -179,44 +247,48 @@ It should be this way, at any rate!
 
 =cut
 
-sub A2CRenderTemplateOpts {
+sub A2C_Render_Template_Opts {
     my ($self, $parms, $key, @vals) = @_;
-    $self->_hash_assign('A2CRenderTemplateOpts', $key, @vals);
+    $self->_hash_assign('A2C_Render_Template_Opts', $key, @vals);
     return;
 }
 
-=head2 A2CSessionClass
+=head1 Apache2::Controller::Session
 
- A2CSessionClass Apache::Session::File
+See L<Apache2::Controller::Session>.
+
+=head2 A2C_Session_Class
+
+ A2C_Session_Class Apache::Session::File
 
 Single argument, the class for the tied session hash.  L<Apache::Session>.
 
 =cut
 
-sub A2CSessionClass {
+sub A2C_Session_Class {
     my ($self, $parms, $class) = @_;
-    $self->{A2CSessionClass} = $class;
+    $self->{A2C_Session_Class} = $class;
 }
 
-=head2 A2CSessionOptions
+=head2 A2C_Session_Opts
 
 Multiple arguments
 
- A2CSessionOptions   Directory       /tmp/sessions
- A2CSessionOptions   LockDirectory   /var/lock/sessions
+ A2C_Session_Opts   Directory       /tmp/sessions
+ A2C_Session_Opts   LockDirectory   /var/lock/sessions
 
 =cut
 
-sub A2CSessionOptions {
+sub A2C_Session_Opts {
     my ($self, $parms, $key, @vals) = @_;
-    $self->_hash_assign('A2CSessionOptions', $key, @vals);
+    $self->_hash_assign('A2C_Session_Opts', $key, @vals);
     return;
 }
 
-=head2 A2CSessionCookieOptions
+=head2 A2C_Session_Cookie_Opts
 
- A2CSessionCookieOptions name    myapp_sessionid
- A2CSessionCookieOptions expires +3M
+ A2C_Session_Cookie_Opts name    myapp_sessionid
+ A2C_Session_Cookie_Opts expires +3M
 
 Multiple arguments.  
 L<Apache2::Controller::Session::Cookie>,
@@ -224,12 +296,16 @@ L<Apache2::Cookie>
 
 =cut
 
-sub A2CSessionCookieOptions {
+sub A2C_Session_Cookie_Opts {
     my ($self, $parms, $key, @vals) = @_;
-    $self->_hash_assign('A2CSessionCookieOptions', $key, @vals);
+    $self->_hash_assign('A2C_Session_Cookie_Opts', $key, @vals);
     return;
 }
 
+=head1 Apache2::Controller::DBI::Connector
+
+See L<Apache2::Controller::DBI::Connector>.
+
 =head2 A2C_DBI_DSN 
 
  A2C_DBI_DSN        DBI:mysql:database=foobar;host=localhost
@@ -271,7 +347,7 @@ sub A2C_DBI_Password {
 
 =head2 A2C_DBI_Options
 
-Multiple arguments
+Multiple arguments.
 
  A2C_DBI_Options    RaiseError  1
  A2C_DBI_Options    AutoCommit  0
@@ -284,6 +360,45 @@ sub A2C_DBI_Options {
     return;
 }
 
+=head2 A2C_DBI_Cleanup
+
+Boolean.  
+
+ A2C_DBI_Cleanup        1
+
+=cut
+
+sub A2C_DBI_Cleanup {
+    my ($self, $parms, $val) = @_;
+    $self->{A2C_DBI_Cleanup} = $val;
+    return;
+}
+
+=head2 A2C_DBI_Pnotes_Name
+
+String value.
+
+ A2C_DBI_Pnotes_Name    reader
+
+=cut
+
+sub A2C_DBI_Pnotes_Name {
+    my ($self, $parms, $val) = @_;
+    $self->{A2C_DBI_Pnotes_Name} = $val;
+    return;
+}
+
+=head2 A2C_DBI_Class
+
+If you subclass DBI, specify the name of your DBI subclass here.
+
+ A2C_DBI_Class      MyApp::DBI
+
+Note that this is connected with a string eval which is slow.
+If you don't use it, it uses a block eval to connect DBI.
+
+=cut
+
 # _hash_assign performs iterate2 options hash assignments in a 
 # consistent way (or so one might hope)
 
