@@ -1,6 +1,6 @@
 package TestApp::HashTree::Baz;
 use base qw( Apache2::Controller );
-our @ALLOWED_METHODS = qw( noz );
+sub allowed_methods {qw( noz )}
 
 sub noz { 
 }
