@@ -1,6 +1,6 @@
 package TestApp::HashTree::Foo;
 use base qw( Apache2::Controller );
-our @ALLOWED_METHODS = qw( default bar );
+sub allowed_methods {qw( default bar )}
 sub default {
 }
 sub bar {
